@@ -352,7 +352,7 @@ class FFmpeg(object):
     def get_size(self, path):
         return filesystem.get_size(path)
 
-    def encode(self, in_filenames, out_filename, options, base_track=0):
+    def encode(self, in_filenames, out_filename, options, base_track=0, create_out_directory=True):
         """
         Encode a set of input files input an output file.
 
@@ -381,6 +381,13 @@ class FFmpeg(object):
         ERROR
         """
         arguments, in_filenames, out_filename, options = self._get_arguments(in_filenames, out_filename, options)
+
+        # Create output directory
+        if create_out_directory:
+            directory = os.path.dirname(out_filename)
+            if directory:
+                filesystem.try_makedirs(directory)
+
         process = self._get_process(arguments)
         try:
             # Get input media duration and size to be able to estimate ETA
